@@ -27,26 +27,26 @@
 </context>
 <context>
     <name>AccountButton</name>
+    <message>
+        <source>Unlogged</source>
+        <translation>Fora de la sessió</translation>
+    </message>
     <message>
         <source>My Favorites</source>
         <translation>Favorits</translation>
     </message>
+    <message>
+        <source>My Feedbacks</source>
+        <translation>Els meus comentaris</translation>
+    </message>
     <message>
         <source>Sign out</source>
         <translation>Surt de la sessió</translation>
     </message>
-    <message>
-        <source>Unlogged</source>
-        <translation>Fora de la sessió</translation>
-    </message>
     <message>
         <source>Sign in</source>
         <translation>Inicieu la sessió</translation>
     </message>
-    <message>
-        <source>My Feedbacks</source>
-        <translation>Els meus comentaris</translation>
-    </message>
 </context>
 <context>
     <name>Card</name>
@@ -95,6 +95,10 @@
         <source>Search</source>
         <translation>Cerca</translation>
     </message>
+    <message>
+        <source>Type:</source>
+        <translation>Tipus:</translation>
+    </message>
     <message>
         <source>All</source>
         <translation>Tot</translation>
@@ -107,6 +111,14 @@
         <source>Suggestions</source>
         <translation>Suggeriments</translation>
     </message>
+    <message>
+        <source>Version:</source>
+        <translation>Versió:</translation>
+    </message>
+    <message>
+        <source>Sort:</source>
+        <translation>Classificació:</translation>
+    </message>
     <message>
         <source>Newest</source>
         <translation>El més nou</translation>
@@ -119,18 +131,6 @@
         <source>Urge</source>
         <translation>Urgent</translation>
     </message>
-    <message>
-        <source>Type:</source>
-        <translation>Tipus:</translation>
-    </message>
-    <message>
-        <source>Version:</source>
-        <translation>Versió:</translation>
-    </message>
-    <message>
-        <source>Sort:</source>
-        <translation>Classificació:</translation>
-    </message>
 </context>
 <context>
     <name>Index</name>
@@ -174,6 +174,10 @@
         <source>Internal Testing</source>
         <translation>Proves internes</translation>
     </message>
+    <message>
+        <source>Global Translation</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Community News</source>
         <translation>Notícies de la comunitat</translation>
@@ -181,6 +185,10 @@
 </context>
 <context>
     <name>List</name>
+    <message>
+        <source>No more items</source>
+        <translation>No hi ha més elements.</translation>
+    </message>
     <message>
         <source>Messages</source>
         <translation>Missatges</translation>
@@ -189,10 +197,6 @@
         <source>Questionaires</source>
         <translation>Qüestionaris</translation>
     </message>
-    <message>
-        <source>No more items</source>
-        <translation>No hi ha més elements.</translation>
-    </message>
 </context>
 <context>
     <name>MyTitleBar</name>
@@ -278,6 +282,10 @@
         <source>Pending</source>
         <translation>Pendent</translation>
     </message>
+    <message>
+        <source>Reproducing</source>
+        <translation>Reproducció</translation>
+    </message>
     <message>
         <source>Confirmed</source>
         <translation>Confirmat</translation>
@@ -302,10 +310,6 @@
         <source>Completed</source>
         <translation>Completat</translation>
     </message>
-    <message>
-        <source>Reproducing</source>
-        <translation>Reproducció</translation>
-    </message>
     <message>
         <source>The issue has not been processed and will not be displayed in the public listing.</source>
         <translation>El problema no s&apos;ha processat i no es mostrarà a la llista pública.</translation>
@@ -361,10 +365,6 @@
         <source>The image file format is not supported for uploading.</source>
         <translation>El format de fitxer d&apos;imatge no és compatible per a la càrrega.</translation>
     </message>
-    <message>
-        <source>Submit Feedback</source>
-        <translation>Envieu comentaris</translation>
-    </message>
     <message>
         <source>[Current Status of the Product]: 
 [Desired Product]: </source>
@@ -381,6 +381,10 @@
 [Resultats esperats]:
 [Resultats reals]:</translation>
     </message>
+    <message>
+        <source>Submit Feedback</source>
+        <translation>Envieu comentaris</translation>
+    </message>
     <message>
         <source>Type：</source>
         <translation>Tipus:</translation>
@@ -405,6 +409,10 @@
         <source>Content：</source>
         <translation>Contingut:</translation>
     </message>
+    <message>
+        <source>Do not fill in multiple issues in one feedback</source>
+        <translation>No afegiu diversos problemes en un sol comentari.</translation>
+    </message>
     <message>
         <source>Do not fill in multiple requirements in one feedback</source>
         <translation>No ompliu diversos requisits en un sol comentari.</translation>
@@ -413,6 +421,10 @@
         <source>Email：</source>
         <translation>Adreça electrònica:</translation>
     </message>
+    <message>
+        <source>Please enter your email</source>
+        <translation>Si us plau, escriviu l&apos;adreça electrònica.</translation>
+    </message>
     <message>
         <source>System Version:</source>
         <translation>Versió del sistema:</translation>
@@ -481,14 +493,6 @@
         <source>Device Information</source>
         <translation>Informació del dispositiu</translation>
     </message>
-    <message>
-        <source>Please enter your email</source>
-        <translation>Si us plau, escriviu l&apos;adreça electrònica.</translation>
-    </message>
-    <message>
-        <source>Do not fill in multiple issues in one feedback</source>
-        <translation>No afegiu diversos problemes en un sol comentari.</translation>
-    </message>
 </context>
 <context>
     <name>TabButton</name>
