@@ -27,26 +27,26 @@
 </context>
 <context>
     <name>AccountButton</name>
+    <message>
+        <source>Unlogged</source>
+        <translation>Nincs bejelentkezve</translation>
+    </message>
     <message>
         <source>My Favorites</source>
         <translation>Kedvenceim</translation>
     </message>
+    <message>
+        <source>My Feedbacks</source>
+        <translation>Visszajelzéseim</translation>
+    </message>
     <message>
         <source>Sign out</source>
         <translation>Kijelentkezés</translation>
     </message>
-    <message>
-        <source>Unlogged</source>
-        <translation>Nincs bejelentkezve</translation>
-    </message>
     <message>
         <source>Sign in</source>
         <translation>Bejelentkezés</translation>
     </message>
-    <message>
-        <source>My Feedbacks</source>
-        <translation>Visszajelzéseim</translation>
-    </message>
 </context>
 <context>
     <name>Card</name>
@@ -93,43 +93,43 @@
     <name>Filter</name>
     <message>
         <source>Search</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>All</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Bug</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Suggestions</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Newest</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Urge</source>
-        <translation type="unfinished"/>
+        <translation>Keresés</translation>
     </message>
     <message>
         <source>Type:</source>
-        <translation type="unfinished"/>
+        <translation>Típus:</translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation>Összes</translation>
+    </message>
+    <message>
+        <source>Bug</source>
+        <translation>Hiba</translation>
+    </message>
+    <message>
+        <source>Suggestions</source>
+        <translation>Javaslatok</translation>
     </message>
     <message>
         <source>Version:</source>
-        <translation type="unfinished"/>
+        <translation>Verzió:</translation>
     </message>
     <message>
         <source>Sort:</source>
-        <translation type="unfinished"/>
+        <translation>Fajta:</translation>
+    </message>
+    <message>
+        <source>Newest</source>
+        <translation>Legújabb</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation>Kedvenc</translation>
+    </message>
+    <message>
+        <source>Urge</source>
+        <translation>Ösztönzés</translation>
     </message>
 </context>
 <context>
@@ -174,6 +174,10 @@
         <source>Internal Testing</source>
         <translation>Belső tesztelés</translation>
     </message>
+    <message>
+        <source>Global Translation</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Community News</source>
         <translation>Közösségi Hírek</translation>
@@ -181,6 +185,10 @@
 </context>
 <context>
     <name>List</name>
+    <message>
+        <source>No more items</source>
+        <translation>Nincs több elem</translation>
+    </message>
     <message>
         <source>Messages</source>
         <translation>Üzenetek</translation>
@@ -189,10 +197,6 @@
         <source>Questionaires</source>
         <translation>Kérdőívek</translation>
     </message>
-    <message>
-        <source>No more items</source>
-        <translation>Nincs több elem</translation>
-    </message>
 </context>
 <context>
     <name>MyTitleBar</name>
@@ -278,6 +282,10 @@
         <source>Pending</source>
         <translation>A további műveletek folytatásához be kell jelentkeznie.</translation>
     </message>
+    <message>
+        <source>Reproducing</source>
+        <translation>Reprodukálás</translation>
+    </message>
     <message>
         <source>Confirmed</source>
         <translation>Megerősítve</translation>
@@ -302,10 +310,6 @@
         <source>Completed</source>
         <translation>Befejezve</translation>
     </message>
-    <message>
-        <source>Reproducing</source>
-        <translation>Reprodukálás</translation>
-    </message>
     <message>
         <source>The issue has not been processed and will not be displayed in the public listing.</source>
         <translation>A probléma feldolgozása nem történt meg, és nem jelenik meg a nyilvános listán.</translation>
@@ -361,10 +365,6 @@
         <source>The image file format is not supported for uploading.</source>
         <translation>A képfájl formátuma nem támogatott a feltöltéshez.</translation>
     </message>
-    <message>
-        <source>Submit Feedback</source>
-        <translation>Visszajelzés küldése</translation>
-    </message>
     <message>
         <source>[Current Status of the Product]: 
 [Desired Product]: </source>
@@ -381,6 +381,10 @@
 [Várható eredmények]: 
 [Jelenlegi eredmények]:</translation>
     </message>
+    <message>
+        <source>Submit Feedback</source>
+        <translation>Visszajelzés küldése</translation>
+    </message>
     <message>
         <source>Type：</source>
         <translation>Típus:</translation>
@@ -405,6 +409,10 @@
         <source>Content：</source>
         <translation>Tartalom:</translation>
     </message>
+    <message>
+        <source>Do not fill in multiple issues in one feedback</source>
+        <translation>Ne töltsön fel több hibajelzést egy visszajelzésben</translation>
+    </message>
     <message>
         <source>Do not fill in multiple requirements in one feedback</source>
         <translation>Ne töltsön ki több követelményt egy visszajelzésben</translation>
@@ -413,6 +421,10 @@
         <source>Email：</source>
         <translation>E-mail:</translation>
     </message>
+    <message>
+        <source>Please enter your email</source>
+        <translation>Kérjük adja meg az e-mail címét</translation>
+    </message>
     <message>
         <source>System Version:</source>
         <translation>Rendszer verzió:</translation>
@@ -481,14 +493,6 @@
         <source>Device Information</source>
         <translation>Eszköz információ</translation>
     </message>
-    <message>
-        <source>Please enter your email</source>
-        <translation>Kérjük adja meg az e-mail címét</translation>
-    </message>
-    <message>
-        <source>Do not fill in multiple issues in one feedback</source>
-        <translation>Ne töltsön fel több hibajelzést egy visszajelzésben</translation>
-    </message>
 </context>
 <context>
     <name>TabButton</name>
