@@ -27,26 +27,26 @@
 </context>
 <context>
     <name>AccountButton</name>
+    <message>
+        <source>Unlogged</source>
+        <translation>Поза системою</translation>
+    </message>
     <message>
         <source>My Favorites</source>
         <translation>Улюблене</translation>
     </message>
+    <message>
+        <source>My Feedbacks</source>
+        <translation>Відгуки</translation>
+    </message>
     <message>
         <source>Sign out</source>
         <translation>Вийти</translation>
     </message>
-    <message>
-        <source>Unlogged</source>
-        <translation>Поза системою</translation>
-    </message>
     <message>
         <source>Sign in</source>
         <translation>Увійти</translation>
     </message>
-    <message>
-        <source>My Feedbacks</source>
-        <translation>Відгуки</translation>
-    </message>
 </context>
 <context>
     <name>Card</name>
@@ -95,6 +95,10 @@
         <source>Search</source>
         <translation>Пошук</translation>
     </message>
+    <message>
+        <source>Type:</source>
+        <translation>Тип:</translation>
+    </message>
     <message>
         <source>All</source>
         <translation>Усі</translation>
@@ -107,6 +111,14 @@
         <source>Suggestions</source>
         <translation>Пропозиції</translation>
     </message>
+    <message>
+        <source>Version:</source>
+        <translation>Версія:</translation>
+    </message>
+    <message>
+        <source>Sort:</source>
+        <translation>Упорядкування:</translation>
+    </message>
     <message>
         <source>Newest</source>
         <translation>Найновіші</translation>
@@ -119,18 +131,6 @@
         <source>Urge</source>
         <translation>Критичні</translation>
     </message>
-    <message>
-        <source>Type:</source>
-        <translation>Тип:</translation>
-    </message>
-    <message>
-        <source>Version:</source>
-        <translation>Версія:</translation>
-    </message>
-    <message>
-        <source>Sort:</source>
-        <translation>Упорядкування:</translation>
-    </message>
 </context>
 <context>
     <name>Index</name>
@@ -174,6 +174,10 @@
         <source>Internal Testing</source>
         <translation>Внутрішнє тестування</translation>
     </message>
+    <message>
+        <source>Global Translation</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Community News</source>
         <translation>Новини спільноти</translation>
@@ -181,6 +185,10 @@
 </context>
 <context>
     <name>List</name>
+    <message>
+        <source>No more items</source>
+        <translation>Більше записів немає</translation>
+    </message>
     <message>
         <source>Messages</source>
         <translation>Повідомлення</translation>
@@ -189,10 +197,6 @@
         <source>Questionaires</source>
         <translation>Опитування</translation>
     </message>
-    <message>
-        <source>No more items</source>
-        <translation>Більше записів немає</translation>
-    </message>
 </context>
 <context>
     <name>MyTitleBar</name>
@@ -278,6 +282,10 @@
         <source>Pending</source>
         <translation>У черзі</translation>
     </message>
+    <message>
+        <source>Reproducing</source>
+        <translation>Відтворюваність</translation>
+    </message>
     <message>
         <source>Confirmed</source>
         <translation>Підтверджено</translation>
@@ -302,10 +310,6 @@
         <source>Completed</source>
         <translation>Завершено</translation>
     </message>
-    <message>
-        <source>Reproducing</source>
-        <translation>Відтворюваність</translation>
-    </message>
     <message>
         <source>The issue has not been processed and will not be displayed in the public listing.</source>
         <translation>Запис вади не було оброблено, і його не буде показано у загальнодоступному списку.</translation>
@@ -361,10 +365,6 @@
         <source>The image file format is not supported for uploading.</source>
         <translation>Не передбачено підтримки вивантаження файлів зображень у цьому форматі.</translation>
     </message>
-    <message>
-        <source>Submit Feedback</source>
-        <translation>Надіслати відгук</translation>
-    </message>
     <message>
         <source>[Current Status of the Product]: 
 [Desired Product]: </source>
@@ -381,6 +381,10 @@
 [Очікувані результати]: 
 [Поточні результати]: </translation>
     </message>
+    <message>
+        <source>Submit Feedback</source>
+        <translation>Надіслати відгук</translation>
+    </message>
     <message>
         <source>Type：</source>
         <translation>Тип:</translation>
@@ -405,6 +409,10 @@
         <source>Content：</source>
         <translation>Вміст:</translation>
     </message>
+    <message>
+        <source>Do not fill in multiple issues in one feedback</source>
+        <translation>Не поєднуйте декілька проблем в одному відгуку</translation>
+    </message>
     <message>
         <source>Do not fill in multiple requirements in one feedback</source>
         <translation>Не вписуйте декілька вимог до одного відгуку</translation>
@@ -413,6 +421,10 @@
         <source>Email：</source>
         <translation>Адреса ел. пошти:</translation>
     </message>
+    <message>
+        <source>Please enter your email</source>
+        <translation>Будь ласка, введіть вашу адресу ел. пошти</translation>
+    </message>
     <message>
         <source>System Version:</source>
         <translation>Версія системи:</translation>
@@ -481,14 +493,6 @@
         <source>Device Information</source>
         <translation>Дані щодо пристрою</translation>
     </message>
-    <message>
-        <source>Please enter your email</source>
-        <translation>Будь ласка, введіть вашу адресу ел. пошти</translation>
-    </message>
-    <message>
-        <source>Do not fill in multiple issues in one feedback</source>
-        <translation>Не поєднуйте декілька проблем в одному відгуку</translation>
-    </message>
 </context>
 <context>
     <name>TabButton</name>
